# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/talent_v4beta1/proto/job_service.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.talent_v4beta1.proto import (
    common_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2,
)
from google.cloud.talent_v4beta1.proto import (
    filters_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_filters__pb2,
)
from google.cloud.talent_v4beta1.proto import (
    histogram_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_histogram__pb2,
)
from google.cloud.talent_v4beta1.proto import (
    job_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/talent_v4beta1/proto/job_service.proto",
    package="google.cloud.talent.v4beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.talent.v4beta1B\017JobServiceProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\242\002\003CTS"
    ),
    serialized_pb=_b(
        '\n3google/cloud/talent_v4beta1/proto/job_service.proto\x12\x1bgoogle.cloud.talent.v4beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a.google/cloud/talent_v4beta1/proto/common.proto\x1a/google/cloud/talent_v4beta1/proto/filters.proto\x1a\x31google/cloud/talent_v4beta1/proto/histogram.proto\x1a+google/cloud/talent_v4beta1/proto/job.proto\x1a#google/longrunning/operations.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a google/protobuf/field_mask.proto\x1a\x17google/rpc/status.proto"w\n\x10\x43reateJobRequest\x12/\n\x06parent\x18\x01 \x01(\tB\x1f\xe0\x41\x02\xfa\x41\x19\x12\x17jobs.googleapis.com/Job\x12\x32\n\x03job\x18\x02 \x01(\x0b\x32 .google.cloud.talent.v4beta1.JobB\x03\xe0\x41\x02">\n\rGetJobRequest\x12-\n\x04name\x18\x01 \x01(\tB\x1f\xe0\x41\x02\xfa\x41\x19\n\x17jobs.googleapis.com/Job"w\n\x10UpdateJobRequest\x12\x32\n\x03job\x18\x01 \x01(\x0b\x32 .google.cloud.talent.v4beta1.JobB\x03\xe0\x41\x02\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"A\n\x10\x44\x65leteJobRequest\x12-\n\x04name\x18\x01 \x01(\tB\x1f\xe0\x41\x02\xfa\x41\x19\n\x17jobs.googleapis.com/Job"^\n\x16\x42\x61tchDeleteJobsRequest\x12/\n\x06parent\x18\x01 \x01(\tB\x1f\xe0\x41\x02\xfa\x41\x19\x12\x17jobs.googleapis.com/Job\x12\x13\n\x06\x66ilter\x18\x02 \x01(\tB\x03\xe0\x41\x02"\xb6\x01\n\x0fListJobsRequest\x12/\n\x06parent\x18\x01 \x01(\tB\x1f\xe0\x41\x02\xfa\x41\x19\x12\x17jobs.googleapis.com/Job\x12\x13\n\x06\x66ilter\x18\x02 \x01(\tB\x03\xe0\x41\x02\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x36\n\x08job_view\x18\x05 \x01(\x0e\x32$.google.cloud.talent.v4beta1.JobView"\x9c\x01\n\x10ListJobsResponse\x12.\n\x04jobs\x18\x01 \x03(\x0b\x32 .google.cloud.talent.v4beta1.Job\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\x12?\n\x08metadata\x18\x03 \x01(\x0b\x32-.google.cloud.talent.v4beta1.ResponseMetadata"\xd0\t\n\x11SearchJobsRequest\x12/\n\x06parent\x18\x01 \x01(\tB\x1f\xe0\x41\x02\xfa\x41\x19\x12\x17jobs.googleapis.com/Job\x12N\n\x0bsearch_mode\x18\x02 \x01(\x0e\x32\x39.google.cloud.talent.v4beta1.SearchJobsRequest.SearchMode\x12K\n\x10request_metadata\x18\x03 \x01(\x0b\x32,.google.cloud.talent.v4beta1.RequestMetadataB\x03\xe0\x41\x02\x12\x38\n\tjob_query\x18\x04 \x01(\x0b\x32%.google.cloud.talent.v4beta1.JobQuery\x12\x19\n\x11\x65nable_broadening\x18\x05 \x01(\x08\x12#\n\x1brequire_precise_result_size\x18\x06 \x01(\x08\x12\x46\n\x11histogram_queries\x18\x07 \x03(\x0b\x32+.google.cloud.talent.v4beta1.HistogramQuery\x12\x36\n\x08job_view\x18\x08 \x01(\x0e\x32$.google.cloud.talent.v4beta1.JobView\x12\x0e\n\x06offset\x18\t \x01(\x05\x12\x11\n\tpage_size\x18\n \x01(\x05\x12\x12\n\npage_token\x18\x0b \x01(\t\x12\x10\n\x08order_by\x18\x0c \x01(\t\x12\x62\n\x15\x64iversification_level\x18\r \x01(\x0e\x32\x43.google.cloud.talent.v4beta1.SearchJobsRequest.DiversificationLevel\x12]\n\x13\x63ustom_ranking_info\x18\x0e \x01(\x0b\x32@.google.cloud.talent.v4beta1.SearchJobsRequest.CustomRankingInfo\x12\x1d\n\x15\x64isable_keyword_match\x18\x10 \x01(\x08\x1a\x9a\x02\n\x11\x43ustomRankingInfo\x12o\n\x10importance_level\x18\x01 \x01(\x0e\x32P.google.cloud.talent.v4beta1.SearchJobsRequest.CustomRankingInfo.ImportanceLevelB\x03\xe0\x41\x02\x12\x1f\n\x12ranking_expression\x18\x02 \x01(\tB\x03\xe0\x41\x02"s\n\x0fImportanceLevel\x12 \n\x1cIMPORTANCE_LEVEL_UNSPECIFIED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x07\n\x03LOW\x10\x02\x12\x08\n\x04MILD\x10\x03\x12\n\n\x06MEDIUM\x10\x04\x12\x08\n\x04HIGH\x10\x05\x12\x0b\n\x07\x45XTREME\x10\x06"R\n\nSearchMode\x12\x1b\n\x17SEARCH_MODE_UNSPECIFIED\x10\x00\x12\x0e\n\nJOB_SEARCH\x10\x01\x12\x17\n\x13\x46\x45\x41TURED_JOB_SEARCH\x10\x02"W\n\x14\x44iversificationLevel\x12%\n!DIVERSIFICATION_LEVEL_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\x12\n\n\x06SIMPLE\x10\x02"\xd7\x06\n\x12SearchJobsResponse\x12R\n\rmatching_jobs\x18\x01 \x03(\x0b\x32;.google.cloud.talent.v4beta1.SearchJobsResponse.MatchingJob\x12R\n\x17histogram_query_results\x18\x02 \x03(\x0b\x32\x31.google.cloud.talent.v4beta1.HistogramQueryResult\x12\x17\n\x0fnext_page_token\x18\x03 \x01(\t\x12?\n\x10location_filters\x18\x04 \x03(\x0b\x32%.google.cloud.talent.v4beta1.Location\x12\x1c\n\x14\x65stimated_total_size\x18\x05 \x01(\x05\x12\x12\n\ntotal_size\x18\x06 \x01(\x05\x12?\n\x08metadata\x18\x07 \x01(\x0b\x32-.google.cloud.talent.v4beta1.ResponseMetadata\x12"\n\x1a\x62roadened_query_jobs_count\x18\x08 \x01(\x05\x12I\n\x10spell_correction\x18\t \x01(\x0b\x32/.google.cloud.talent.v4beta1.SpellingCorrection\x1a\xdc\x01\n\x0bMatchingJob\x12-\n\x03job\x18\x01 \x01(\x0b\x32 .google.cloud.talent.v4beta1.Job\x12\x13\n\x0bjob_summary\x18\x02 \x01(\t\x12\x19\n\x11job_title_snippet\x18\x03 \x01(\t\x12\x1b\n\x13search_text_snippet\x18\x04 \x01(\t\x12Q\n\x0c\x63ommute_info\x18\x05 \x01(\x0b\x32;.google.cloud.talent.v4beta1.SearchJobsResponse.CommuteInfo\x1a~\n\x0b\x43ommuteInfo\x12;\n\x0cjob_location\x18\x01 \x01(\x0b\x32%.google.cloud.talent.v4beta1.Location\x12\x32\n\x0ftravel_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.Duration"~\n\x16\x42\x61tchCreateJobsRequest\x12/\n\x06parent\x18\x01 \x01(\tB\x1f\xe0\x41\x02\xfa\x41\x19\x12\x17jobs.googleapis.com/Job\x12\x33\n\x04jobs\x18\x02 \x03(\x0b\x32 .google.cloud.talent.v4beta1.JobB\x03\xe0\x41\x02"\xaf\x01\n\x16\x42\x61tchUpdateJobsRequest\x12/\n\x06parent\x18\x01 \x01(\tB\x1f\xe0\x41\x02\xfa\x41\x19\x12\x17jobs.googleapis.com/Job\x12\x33\n\x04jobs\x18\x02 \x03(\x0b\x32 .google.cloud.talent.v4beta1.JobB\x03\xe0\x41\x02\x12/\n\x0bupdate_mask\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"\xc4\x01\n\x12JobOperationResult\x12N\n\x0bjob_results\x18\x01 \x03(\x0b\x32\x39.google.cloud.talent.v4beta1.JobOperationResult.JobResult\x1a^\n\tJobResult\x12-\n\x03job\x18\x01 \x01(\x0b\x32 .google.cloud.talent.v4beta1.Job\x12"\n\x06status\x18\x02 \x01(\x0b\x32\x12.google.rpc.Status*v\n\x07JobView\x12\x18\n\x14JOB_VIEW_UNSPECIFIED\x10\x00\x12\x14\n\x10JOB_VIEW_ID_ONLY\x10\x01\x12\x14\n\x10JOB_VIEW_MINIMAL\x10\x02\x12\x12\n\x0eJOB_VIEW_SMALL\x10\x03\x12\x11\n\rJOB_VIEW_FULL\x10\x04\x32\xce\x12\n\nJobService\x12\xc9\x01\n\tCreateJob\x12-.google.cloud.talent.v4beta1.CreateJobRequest\x1a .google.cloud.talent.v4beta1.Job"k\x82\xd3\xe4\x93\x02X"+/v4beta1/{parent=projects/*/tenants/*}/jobs:\x01*Z&"!/v4beta1/{parent=projects/*}/jobs:\x01*\xda\x41\nparent,job\x12\x9b\x02\n\x0f\x42\x61tchCreateJobs\x12\x33.google.cloud.talent.v4beta1.BatchCreateJobsRequest\x1a\x1d.google.longrunning.Operation"\xb3\x01\x82\xd3\xe4\x93\x02p"7/v4beta1/{parent=projects/*/tenants/*}/jobs:batchCreate:\x01*Z2"-/v4beta1/{parent=projects/*}/jobs:batchCreate:\x01*\xda\x41\x0bparent,jobs\xca\x41,\n\x12JobOperationResult\x12\x16\x42\x61tchOperationMetadata\x12\xb7\x01\n\x06GetJob\x12*.google.cloud.talent.v4beta1.GetJobRequest\x1a .google.cloud.talent.v4beta1.Job"_\x82\xd3\xe4\x93\x02R\x12+/v4beta1/{name=projects/*/tenants/*/jobs/*}Z#\x12!/v4beta1/{name=projects/*/jobs/*}\xda\x41\x04name\x12\xca\x01\n\tUpdateJob\x12-.google.cloud.talent.v4beta1.UpdateJobRequest\x1a .google.cloud.talent.v4beta1.Job"l\x82\xd3\xe4\x93\x02`2//v4beta1/{job.name=projects/*/tenants/*/jobs/*}:\x01*Z*2%/v4beta1/{job.name=projects/*/jobs/*}:\x01*\xda\x41\x03job\x12\x9b\x02\n\x0f\x42\x61tchUpdateJobs\x12\x33.google.cloud.talent.v4beta1.BatchUpdateJobsRequest\x1a\x1d.google.longrunning.Operation"\xb3\x01\x82\xd3\xe4\x93\x02p"7/v4beta1/{parent=projects/*/tenants/*}/jobs:batchUpdate:\x01*Z2"-/v4beta1/{parent=projects/*}/jobs:batchUpdate:\x01*\xda\x41\x0bparent,jobs\xca\x41,\n\x12JobOperationResult\x12\x16\x42\x61tchOperationMetadata\x12\xb3\x01\n\tDeleteJob\x12-.google.cloud.talent.v4beta1.DeleteJobRequest\x1a\x16.google.protobuf.Empty"_\x82\xd3\xe4\x93\x02R*+/v4beta1/{name=projects/*/tenants/*/jobs/*}Z#*!/v4beta1/{name=projects/*/jobs/*}\xda\x41\x04name\x12\xe4\x01\n\x0f\x42\x61tchDeleteJobs\x12\x33.google.cloud.talent.v4beta1.BatchDeleteJobsRequest\x1a\x16.google.protobuf.Empty"\x83\x01\x82\xd3\xe4\x93\x02m"7/v4beta1/{parent=projects/*/tenants/*}/jobs:batchDelete:\x01*Z/"-/v4beta1/{parent=projects/*}/jobs:batchDelete\xda\x41\rparent,filter\x12\xd1\x01\n\x08ListJobs\x12,.google.cloud.talent.v4beta1.ListJobsRequest\x1a-.google.cloud.talent.v4beta1.ListJobsResponse"h\x82\xd3\xe4\x93\x02R\x12+/v4beta1/{parent=projects/*/tenants/*}/jobsZ#\x12!/v4beta1/{parent=projects/*}/jobs\xda\x41\rparent,filter\x12\xdb\x01\n\nSearchJobs\x12..google.cloud.talent.v4beta1.SearchJobsRequest\x1a/.google.cloud.talent.v4beta1.SearchJobsResponse"l\x82\xd3\xe4\x93\x02\x66"2/v4beta1/{parent=projects/*/tenants/*}/jobs:search:\x01*Z-"(/v4beta1/{parent=projects/*}/jobs:search:\x01*\x12\xf3\x01\n\x12SearchJobsForAlert\x12..google.cloud.talent.v4beta1.SearchJobsRequest\x1a/.google.cloud.talent.v4beta1.SearchJobsResponse"|\x82\xd3\xe4\x93\x02v":/v4beta1/{parent=projects/*/tenants/*}/jobs:searchForAlert:\x01*Z5"0/v4beta1/{parent=projects/*}/jobs:searchForAlert:\x01*\x1al\xca\x41\x13jobs.googleapis.com\xd2\x41Shttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/jobsB}\n\x1f\x63om.google.cloud.talent.v4beta1B\x0fJobServiceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\xa2\x02\x03\x43TSb\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_filters__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_histogram__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2.DESCRIPTOR,
        google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
        google_dot_rpc_dot_status__pb2.DESCRIPTOR,
    ],
)

_JOBVIEW = _descriptor.EnumDescriptor(
    name="JobView",
    full_name="google.cloud.talent.v4beta1.JobView",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="JOB_VIEW_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="JOB_VIEW_ID_ONLY",
            index=1,
            number=1,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="JOB_VIEW_MINIMAL",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="JOB_VIEW_SMALL", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="JOB_VIEW_FULL", index=4, number=4, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=3987,
    serialized_end=4105,
)
_sym_db.RegisterEnumDescriptor(_JOBVIEW)

JobView = enum_type_wrapper.EnumTypeWrapper(_JOBVIEW)
JOB_VIEW_UNSPECIFIED = 0
JOB_VIEW_ID_ONLY = 1
JOB_VIEW_MINIMAL = 2
JOB_VIEW_SMALL = 3
JOB_VIEW_FULL = 4


_SEARCHJOBSREQUEST_CUSTOMRANKINGINFO_IMPORTANCELEVEL = _descriptor.EnumDescriptor(
    name="ImportanceLevel",
    full_name="google.cloud.talent.v4beta1.SearchJobsRequest.CustomRankingInfo.ImportanceLevel",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="IMPORTANCE_LEVEL_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="NONE", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="LOW", index=2, number=2, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="MILD", index=3, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="MEDIUM", index=4, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="HIGH", index=5, number=5, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="EXTREME", index=6, number=6, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2334,
    serialized_end=2449,
)
_sym_db.RegisterEnumDescriptor(_SEARCHJOBSREQUEST_CUSTOMRANKINGINFO_IMPORTANCELEVEL)

_SEARCHJOBSREQUEST_SEARCHMODE = _descriptor.EnumDescriptor(
    name="SearchMode",
    full_name="google.cloud.talent.v4beta1.SearchJobsRequest.SearchMode",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="SEARCH_MODE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="JOB_SEARCH", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="FEATURED_JOB_SEARCH",
            index=2,
            number=2,
            serialized_options=None,
            type=None,
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2451,
    serialized_end=2533,
)
_sym_db.RegisterEnumDescriptor(_SEARCHJOBSREQUEST_SEARCHMODE)

_SEARCHJOBSREQUEST_DIVERSIFICATIONLEVEL = _descriptor.EnumDescriptor(
    name="DiversificationLevel",
    full_name="google.cloud.talent.v4beta1.SearchJobsRequest.DiversificationLevel",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="DIVERSIFICATION_LEVEL_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="DISABLED", index=1, number=1, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="SIMPLE", index=2, number=2, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=2535,
    serialized_end=2622,
)
_sym_db.RegisterEnumDescriptor(_SEARCHJOBSREQUEST_DIVERSIFICATIONLEVEL)


_CREATEJOBREQUEST = _descriptor.Descriptor(
    name="CreateJobRequest",
    full_name="google.cloud.talent.v4beta1.CreateJobRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.talent.v4beta1.CreateJobRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002\372A\031\022\027jobs.googleapis.com/Job"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job",
            full_name="google.cloud.talent.v4beta1.CreateJobRequest.job",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=576,
    serialized_end=695,
)


_GETJOBREQUEST = _descriptor.Descriptor(
    name="GetJobRequest",
    full_name="google.cloud.talent.v4beta1.GetJobRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.talent.v4beta1.GetJobRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002\372A\031\n\027jobs.googleapis.com/Job"),
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=697,
    serialized_end=759,
)


_UPDATEJOBREQUEST = _descriptor.Descriptor(
    name="UpdateJobRequest",
    full_name="google.cloud.talent.v4beta1.UpdateJobRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="job",
            full_name="google.cloud.talent.v4beta1.UpdateJobRequest.job",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.talent.v4beta1.UpdateJobRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=761,
    serialized_end=880,
)


_DELETEJOBREQUEST = _descriptor.Descriptor(
    name="DeleteJobRequest",
    full_name="google.cloud.talent.v4beta1.DeleteJobRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.talent.v4beta1.DeleteJobRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002\372A\031\n\027jobs.googleapis.com/Job"),
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=882,
    serialized_end=947,
)


_BATCHDELETEJOBSREQUEST = _descriptor.Descriptor(
    name="BatchDeleteJobsRequest",
    full_name="google.cloud.talent.v4beta1.BatchDeleteJobsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.talent.v4beta1.BatchDeleteJobsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002\372A\031\022\027jobs.googleapis.com/Job"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="filter",
            full_name="google.cloud.talent.v4beta1.BatchDeleteJobsRequest.filter",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=949,
    serialized_end=1043,
)


_LISTJOBSREQUEST = _descriptor.Descriptor(
    name="ListJobsRequest",
    full_name="google.cloud.talent.v4beta1.ListJobsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.talent.v4beta1.ListJobsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002\372A\031\022\027jobs.googleapis.com/Job"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="filter",
            full_name="google.cloud.talent.v4beta1.ListJobsRequest.filter",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.talent.v4beta1.ListJobsRequest.page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.talent.v4beta1.ListJobsRequest.page_size",
            index=3,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_view",
            full_name="google.cloud.talent.v4beta1.ListJobsRequest.job_view",
            index=4,
            number=5,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1046,
    serialized_end=1228,
)


_LISTJOBSRESPONSE = _descriptor.Descriptor(
    name="ListJobsResponse",
    full_name="google.cloud.talent.v4beta1.ListJobsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="jobs",
            full_name="google.cloud.talent.v4beta1.ListJobsResponse.jobs",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.talent.v4beta1.ListJobsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="google.cloud.talent.v4beta1.ListJobsResponse.metadata",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1231,
    serialized_end=1387,
)


_SEARCHJOBSREQUEST_CUSTOMRANKINGINFO = _descriptor.Descriptor(
    name="CustomRankingInfo",
    full_name="google.cloud.talent.v4beta1.SearchJobsRequest.CustomRankingInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="importance_level",
            full_name="google.cloud.talent.v4beta1.SearchJobsRequest.CustomRankingInfo.importance_level",
            index=0,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="ranking_expression",
            full_name="google.cloud.talent.v4beta1.SearchJobsRequest.CustomRankingInfo.ranking_expression",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[_SEARCHJOBSREQUEST_CUSTOMRANKINGINFO_IMPORTANCELEVEL],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2167,
    serialized_end=2449,
)

_SEARCHJOBSREQUEST = _descriptor.Descriptor(
    name="SearchJobsRequest",
    full_name="google.cloud.talent.v4beta1.SearchJobsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.talent.v4beta1.SearchJobsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002\372A\031\022\027jobs.googleapis.com/Job"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="search_mode",
            full_name="google.cloud.talent.v4beta1.SearchJobsRequest.search_mode",
            index=1,
            number=2,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="request_metadata",
            full_name="google.cloud.talent.v4beta1.SearchJobsRequest.request_metadata",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_query",
            full_name="google.cloud.talent.v4beta1.SearchJobsRequest.job_query",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="enable_broadening",
            full_name="google.cloud.talent.v4beta1.SearchJobsRequest.enable_broadening",
            index=4,
            number=5,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="require_precise_result_size",
            full_name="google.cloud.talent.v4beta1.SearchJobsRequest.require_precise_result_size",
            index=5,
            number=6,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="histogram_queries",
            full_name="google.cloud.talent.v4beta1.SearchJobsRequest.histogram_queries",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_view",
            full_name="google.cloud.talent.v4beta1.SearchJobsRequest.job_view",
            index=7,
            number=8,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="offset",
            full_name="google.cloud.talent.v4beta1.SearchJobsRequest.offset",
            index=8,
            number=9,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.talent.v4beta1.SearchJobsRequest.page_size",
            index=9,
            number=10,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.talent.v4beta1.SearchJobsRequest.page_token",
            index=10,
            number=11,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="order_by",
            full_name="google.cloud.talent.v4beta1.SearchJobsRequest.order_by",
            index=11,
            number=12,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="diversification_level",
            full_name="google.cloud.talent.v4beta1.SearchJobsRequest.diversification_level",
            index=12,
            number=13,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="custom_ranking_info",
            full_name="google.cloud.talent.v4beta1.SearchJobsRequest.custom_ranking_info",
            index=13,
            number=14,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="disable_keyword_match",
            full_name="google.cloud.talent.v4beta1.SearchJobsRequest.disable_keyword_match",
            index=14,
            number=16,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_SEARCHJOBSREQUEST_CUSTOMRANKINGINFO],
    enum_types=[_SEARCHJOBSREQUEST_SEARCHMODE, _SEARCHJOBSREQUEST_DIVERSIFICATIONLEVEL],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1390,
    serialized_end=2622,
)


_SEARCHJOBSRESPONSE_MATCHINGJOB = _descriptor.Descriptor(
    name="MatchingJob",
    full_name="google.cloud.talent.v4beta1.SearchJobsResponse.MatchingJob",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="job",
            full_name="google.cloud.talent.v4beta1.SearchJobsResponse.MatchingJob.job",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_summary",
            full_name="google.cloud.talent.v4beta1.SearchJobsResponse.MatchingJob.job_summary",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="job_title_snippet",
            full_name="google.cloud.talent.v4beta1.SearchJobsResponse.MatchingJob.job_title_snippet",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="search_text_snippet",
            full_name="google.cloud.talent.v4beta1.SearchJobsResponse.MatchingJob.search_text_snippet",
            index=3,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="commute_info",
            full_name="google.cloud.talent.v4beta1.SearchJobsResponse.MatchingJob.commute_info",
            index=4,
            number=5,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3132,
    serialized_end=3352,
)

_SEARCHJOBSRESPONSE_COMMUTEINFO = _descriptor.Descriptor(
    name="CommuteInfo",
    full_name="google.cloud.talent.v4beta1.SearchJobsResponse.CommuteInfo",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="job_location",
            full_name="google.cloud.talent.v4beta1.SearchJobsResponse.CommuteInfo.job_location",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="travel_duration",
            full_name="google.cloud.talent.v4beta1.SearchJobsResponse.CommuteInfo.travel_duration",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3354,
    serialized_end=3480,
)

_SEARCHJOBSRESPONSE = _descriptor.Descriptor(
    name="SearchJobsResponse",
    full_name="google.cloud.talent.v4beta1.SearchJobsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="matching_jobs",
            full_name="google.cloud.talent.v4beta1.SearchJobsResponse.matching_jobs",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="histogram_query_results",
            full_name="google.cloud.talent.v4beta1.SearchJobsResponse.histogram_query_results",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.talent.v4beta1.SearchJobsResponse.next_page_token",
            index=2,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="location_filters",
            full_name="google.cloud.talent.v4beta1.SearchJobsResponse.location_filters",
            index=3,
            number=4,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="estimated_total_size",
            full_name="google.cloud.talent.v4beta1.SearchJobsResponse.estimated_total_size",
            index=4,
            number=5,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="total_size",
            full_name="google.cloud.talent.v4beta1.SearchJobsResponse.total_size",
            index=5,
            number=6,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="metadata",
            full_name="google.cloud.talent.v4beta1.SearchJobsResponse.metadata",
            index=6,
            number=7,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="broadened_query_jobs_count",
            full_name="google.cloud.talent.v4beta1.SearchJobsResponse.broadened_query_jobs_count",
            index=7,
            number=8,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="spell_correction",
            full_name="google.cloud.talent.v4beta1.SearchJobsResponse.spell_correction",
            index=8,
            number=9,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[_SEARCHJOBSRESPONSE_MATCHINGJOB, _SEARCHJOBSRESPONSE_COMMUTEINFO],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2625,
    serialized_end=3480,
)


_BATCHCREATEJOBSREQUEST = _descriptor.Descriptor(
    name="BatchCreateJobsRequest",
    full_name="google.cloud.talent.v4beta1.BatchCreateJobsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.talent.v4beta1.BatchCreateJobsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002\372A\031\022\027jobs.googleapis.com/Job"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="jobs",
            full_name="google.cloud.talent.v4beta1.BatchCreateJobsRequest.jobs",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3482,
    serialized_end=3608,
)


_BATCHUPDATEJOBSREQUEST = _descriptor.Descriptor(
    name="BatchUpdateJobsRequest",
    full_name="google.cloud.talent.v4beta1.BatchUpdateJobsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.talent.v4beta1.BatchUpdateJobsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002\372A\031\022\027jobs.googleapis.com/Job"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="jobs",
            full_name="google.cloud.talent.v4beta1.BatchUpdateJobsRequest.jobs",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.talent.v4beta1.BatchUpdateJobsRequest.update_mask",
            index=2,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3611,
    serialized_end=3786,
)


_JOBOPERATIONRESULT_JOBRESULT = _descriptor.Descriptor(
    name="JobResult",
    full_name="google.cloud.talent.v4beta1.JobOperationResult.JobResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="job",
            full_name="google.cloud.talent.v4beta1.JobOperationResult.JobResult.job",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="status",
            full_name="google.cloud.talent.v4beta1.JobOperationResult.JobResult.status",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3891,
    serialized_end=3985,
)

_JOBOPERATIONRESULT = _descriptor.Descriptor(
    name="JobOperationResult",
    full_name="google.cloud.talent.v4beta1.JobOperationResult",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="job_results",
            full_name="google.cloud.talent.v4beta1.JobOperationResult.job_results",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[_JOBOPERATIONRESULT_JOBRESULT],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=3789,
    serialized_end=3985,
)

_CREATEJOBREQUEST.fields_by_name[
    "job"
].message_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2._JOB
_UPDATEJOBREQUEST.fields_by_name[
    "job"
].message_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2._JOB
_UPDATEJOBREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_LISTJOBSREQUEST.fields_by_name["job_view"].enum_type = _JOBVIEW
_LISTJOBSRESPONSE.fields_by_name[
    "jobs"
].message_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2._JOB
_LISTJOBSRESPONSE.fields_by_name[
    "metadata"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._RESPONSEMETADATA
)
_SEARCHJOBSREQUEST_CUSTOMRANKINGINFO.fields_by_name[
    "importance_level"
].enum_type = _SEARCHJOBSREQUEST_CUSTOMRANKINGINFO_IMPORTANCELEVEL
_SEARCHJOBSREQUEST_CUSTOMRANKINGINFO.containing_type = _SEARCHJOBSREQUEST
_SEARCHJOBSREQUEST_CUSTOMRANKINGINFO_IMPORTANCELEVEL.containing_type = (
    _SEARCHJOBSREQUEST_CUSTOMRANKINGINFO
)
_SEARCHJOBSREQUEST.fields_by_name[
    "search_mode"
].enum_type = _SEARCHJOBSREQUEST_SEARCHMODE
_SEARCHJOBSREQUEST.fields_by_name[
    "request_metadata"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._REQUESTMETADATA
)
_SEARCHJOBSREQUEST.fields_by_name[
    "job_query"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_filters__pb2._JOBQUERY
)
_SEARCHJOBSREQUEST.fields_by_name[
    "histogram_queries"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_histogram__pb2._HISTOGRAMQUERY
)
_SEARCHJOBSREQUEST.fields_by_name["job_view"].enum_type = _JOBVIEW
_SEARCHJOBSREQUEST.fields_by_name[
    "diversification_level"
].enum_type = _SEARCHJOBSREQUEST_DIVERSIFICATIONLEVEL
_SEARCHJOBSREQUEST.fields_by_name[
    "custom_ranking_info"
].message_type = _SEARCHJOBSREQUEST_CUSTOMRANKINGINFO
_SEARCHJOBSREQUEST_SEARCHMODE.containing_type = _SEARCHJOBSREQUEST
_SEARCHJOBSREQUEST_DIVERSIFICATIONLEVEL.containing_type = _SEARCHJOBSREQUEST
_SEARCHJOBSRESPONSE_MATCHINGJOB.fields_by_name[
    "job"
].message_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2._JOB
_SEARCHJOBSRESPONSE_MATCHINGJOB.fields_by_name[
    "commute_info"
].message_type = _SEARCHJOBSRESPONSE_COMMUTEINFO
_SEARCHJOBSRESPONSE_MATCHINGJOB.containing_type = _SEARCHJOBSRESPONSE
_SEARCHJOBSRESPONSE_COMMUTEINFO.fields_by_name[
    "job_location"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._LOCATION
)
_SEARCHJOBSRESPONSE_COMMUTEINFO.fields_by_name[
    "travel_duration"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_SEARCHJOBSRESPONSE_COMMUTEINFO.containing_type = _SEARCHJOBSRESPONSE
_SEARCHJOBSRESPONSE.fields_by_name[
    "matching_jobs"
].message_type = _SEARCHJOBSRESPONSE_MATCHINGJOB
_SEARCHJOBSRESPONSE.fields_by_name[
    "histogram_query_results"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_histogram__pb2._HISTOGRAMQUERYRESULT
)
_SEARCHJOBSRESPONSE.fields_by_name[
    "location_filters"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._LOCATION
)
_SEARCHJOBSRESPONSE.fields_by_name[
    "metadata"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._RESPONSEMETADATA
)
_SEARCHJOBSRESPONSE.fields_by_name[
    "spell_correction"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_common__pb2._SPELLINGCORRECTION
)
_BATCHCREATEJOBSREQUEST.fields_by_name[
    "jobs"
].message_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2._JOB
_BATCHUPDATEJOBSREQUEST.fields_by_name[
    "jobs"
].message_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2._JOB
_BATCHUPDATEJOBSREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_JOBOPERATIONRESULT_JOBRESULT.fields_by_name[
    "job"
].message_type = google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2._JOB
_JOBOPERATIONRESULT_JOBRESULT.fields_by_name[
    "status"
].message_type = google_dot_rpc_dot_status__pb2._STATUS
_JOBOPERATIONRESULT_JOBRESULT.containing_type = _JOBOPERATIONRESULT
_JOBOPERATIONRESULT.fields_by_name[
    "job_results"
].message_type = _JOBOPERATIONRESULT_JOBRESULT
DESCRIPTOR.message_types_by_name["CreateJobRequest"] = _CREATEJOBREQUEST
DESCRIPTOR.message_types_by_name["GetJobRequest"] = _GETJOBREQUEST
DESCRIPTOR.message_types_by_name["UpdateJobRequest"] = _UPDATEJOBREQUEST
DESCRIPTOR.message_types_by_name["DeleteJobRequest"] = _DELETEJOBREQUEST
DESCRIPTOR.message_types_by_name["BatchDeleteJobsRequest"] = _BATCHDELETEJOBSREQUEST
DESCRIPTOR.message_types_by_name["ListJobsRequest"] = _LISTJOBSREQUEST
DESCRIPTOR.message_types_by_name["ListJobsResponse"] = _LISTJOBSRESPONSE
DESCRIPTOR.message_types_by_name["SearchJobsRequest"] = _SEARCHJOBSREQUEST
DESCRIPTOR.message_types_by_name["SearchJobsResponse"] = _SEARCHJOBSRESPONSE
DESCRIPTOR.message_types_by_name["BatchCreateJobsRequest"] = _BATCHCREATEJOBSREQUEST
DESCRIPTOR.message_types_by_name["BatchUpdateJobsRequest"] = _BATCHUPDATEJOBSREQUEST
DESCRIPTOR.message_types_by_name["JobOperationResult"] = _JOBOPERATIONRESULT
DESCRIPTOR.enum_types_by_name["JobView"] = _JOBVIEW
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateJobRequest = _reflection.GeneratedProtocolMessageType(
    "CreateJobRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CREATEJOBREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.job_service_pb2",
        __doc__="""Create job request.
  
  
  Attributes:
      parent:
          Required. The resource name of the tenant under which the job
          is created.  The format is
          "projects/{project\_id}/tenants/{tenant\_id}". For example,
          "projects/foo/tenant/bar". If tenant id is unspecified a
          default tenant is created. For example, "projects/foo".
      job:
          Required. The Job to be created.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.CreateJobRequest)
    ),
)
_sym_db.RegisterMessage(CreateJobRequest)

GetJobRequest = _reflection.GeneratedProtocolMessageType(
    "GetJobRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETJOBREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.job_service_pb2",
        __doc__="""Get job request.
  
  
  Attributes:
      name:
          Required. The resource name of the job to retrieve.  The
          format is
          "projects/{project\_id}/tenants/{tenant\_id}/jobs/{job\_id}".
          For example, "projects/foo/tenants/bar/jobs/baz".  If tenant
          id is unspecified, the default tenant is used. For example,
          "projects/foo/jobs/bar".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.GetJobRequest)
    ),
)
_sym_db.RegisterMessage(GetJobRequest)

UpdateJobRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateJobRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATEJOBREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.job_service_pb2",
        __doc__="""Update job request.
  
  
  Attributes:
      job:
          Required. The Job to be updated.
      update_mask:
          Strongly recommended for the best service experience.  If [upd
          ate\_mask][google.cloud.talent.v4beta1.UpdateJobRequest.update
          \_mask] is provided, only the specified fields in
          [job][google.cloud.talent.v4beta1.UpdateJobRequest.job] are
          updated. Otherwise all the fields are updated.  A field mask
          to restrict the fields that are updated. Only top level fields
          of [Job][google.cloud.talent.v4beta1.Job] are supported.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.UpdateJobRequest)
    ),
)
_sym_db.RegisterMessage(UpdateJobRequest)

DeleteJobRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteJobRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DELETEJOBREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.job_service_pb2",
        __doc__="""Delete job request.
  
  
  Attributes:
      name:
          Required. The resource name of the job to be deleted.  The
          format is
          "projects/{project\_id}/tenants/{tenant\_id}/jobs/{job\_id}".
          For example, "projects/foo/tenants/bar/jobs/baz".  If tenant
          id is unspecified, the default tenant is used. For example,
          "projects/foo/jobs/bar".
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.DeleteJobRequest)
    ),
)
_sym_db.RegisterMessage(DeleteJobRequest)

BatchDeleteJobsRequest = _reflection.GeneratedProtocolMessageType(
    "BatchDeleteJobsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_BATCHDELETEJOBSREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.job_service_pb2",
        __doc__="""Batch delete jobs request.
  
  
  Attributes:
      parent:
          Required. The resource name of the tenant under which the job
          is created.  The format is
          "projects/{project\_id}/tenants/{tenant\_id}". For example,
          "projects/foo/tenant/bar". If tenant id is unspecified, a
          default tenant is created. For example, "projects/foo".
      filter:
          Required. The filter string specifies the jobs to be deleted.
          Supported operator: =, AND  The fields eligible for filtering
          are:  -  ``companyName`` (Required) -  ``requisitionId``
          (Required)  Sample Query: companyName =
          "projects/foo/companies/bar" AND requisitionId = "req-1"
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.BatchDeleteJobsRequest)
    ),
)
_sym_db.RegisterMessage(BatchDeleteJobsRequest)

ListJobsRequest = _reflection.GeneratedProtocolMessageType(
    "ListJobsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTJOBSREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.job_service_pb2",
        __doc__="""List jobs request.
  
  
  Attributes:
      parent:
          Required. The resource name of the tenant under which the job
          is created.  The format is
          "projects/{project\_id}/tenants/{tenant\_id}". For example,
          "projects/foo/tenant/bar". If tenant id is unspecified, a
          default tenant is created. For example, "projects/foo".
      filter:
          Required. The filter string specifies the jobs to be
          enumerated.  Supported operator: =, AND  The fields eligible
          for filtering are:  -  ``companyName`` (Required) -
          ``requisitionId`` -  ``status`` Available values: OPEN,
          EXPIRED, ALL. Defaults to OPEN if    no value is specified.
          Sample Query:  -  companyName =
          "projects/foo/tenants/bar/companies/baz" -  companyName =
          "projects/foo/tenants/bar/companies/baz" AND    requisitionId
          = "req-1" -  companyName =
          "projects/foo/tenants/bar/companies/baz" AND status =
          "EXPIRED"
      page_token:
          The starting point of a query result.
      page_size:
          The maximum number of jobs to be returned per page of results.
          If [job\_view][google.cloud.talent.v4beta1.ListJobsRequest.job
          \_view] is set to [JobView.JOB\_VIEW\_ID\_ONLY][google.cloud.t
          alent.v4beta1.JobView.JOB\_VIEW\_ID\_ONLY], the maximum
          allowed page size is 1000. Otherwise, the maximum allowed page
          size is 100.  Default is 100 if empty or a number < 1 is
          specified.
      job_view:
          The desired job attributes returned for jobs in the search
          response. Defaults to [JobView.JOB\_VIEW\_FULL][google.cloud.t
          alent.v4beta1.JobView.JOB\_VIEW\_FULL] if no value is
          specified.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.ListJobsRequest)
    ),
)
_sym_db.RegisterMessage(ListJobsRequest)

ListJobsResponse = _reflection.GeneratedProtocolMessageType(
    "ListJobsResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTJOBSRESPONSE,
        __module__="google.cloud.talent_v4beta1.proto.job_service_pb2",
        __doc__="""List jobs response.
  
  
  Attributes:
      jobs:
          The Jobs for a given company.  The maximum number of items
          returned is based on the limit field provided in the request.
      next_page_token:
          A token to retrieve the next page of results.
      metadata:
          Additional information for the API invocation, such as the
          request tracking id.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.ListJobsResponse)
    ),
)
_sym_db.RegisterMessage(ListJobsResponse)

SearchJobsRequest = _reflection.GeneratedProtocolMessageType(
    "SearchJobsRequest",
    (_message.Message,),
    dict(
        CustomRankingInfo=_reflection.GeneratedProtocolMessageType(
            "CustomRankingInfo",
            (_message.Message,),
            dict(
                DESCRIPTOR=_SEARCHJOBSREQUEST_CUSTOMRANKINGINFO,
                __module__="google.cloud.talent_v4beta1.proto.job_service_pb2",
                __doc__="""Custom ranking information for
    [SearchJobsRequest][google.cloud.talent.v4beta1.SearchJobsRequest].
    
    
    Attributes:
        importance_level:
            Required. Controls over how important the score of [CustomRank
            ingInfo.ranking\_expression][google.cloud.talent.v4beta1.Searc
            hJobsRequest.CustomRankingInfo.ranking\_expression] gets
            applied to job's final ranking position.  An error is thrown
            if not specified.
        ranking_expression:
            Required. Controls over how job documents get ranked on top of
            existing relevance score (determined by API algorithm). A
            combination of the ranking expression and relevance score is
            used to determine job's final ranking position.  The syntax
            for this expression is a subset of Google SQL syntax.
            Supported operators are: +, -, \*, /, where the left and right
            side of the operator is either a numeric [Job.custom\_attribut
            es][google.cloud.talent.v4beta1.Job.custom\_attributes] key,
            integer/double value or an expression that can be evaluated to
            a number.  Parenthesis are supported to adjust calculation
            precedence. The expression must be < 100 characters in length.
            The expression is considered invalid for a job if the
            expression references custom attributes that are not populated
            on the job or if the expression results in a divide by zero.
            If an expression is invalid for a job, that job is demoted to
            the end of the results.  Sample ranking expression (year + 25)
            \* 0.25 - (freshness / 0.5)
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.SearchJobsRequest.CustomRankingInfo)
            ),
        ),
        DESCRIPTOR=_SEARCHJOBSREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.job_service_pb2",
        __doc__="""The Request body of the ``SearchJobs`` call.
  
  
  Attributes:
      parent:
          Required. The resource name of the tenant to search within.
          The format is "projects/{project\_id}/tenants/{tenant\_id}".
          For example, "projects/foo/tenant/bar". If tenant id is
          unspecified, a default tenant is created. For example,
          "projects/foo".
      search_mode:
          Mode of a search.  Defaults to [SearchMode.JOB\_SEARCH][google
          .cloud.talent.v4beta1.SearchJobsRequest.SearchMode.JOB\_SEARCH
          ].
      request_metadata:
          Required. The meta information collected about the job
          searcher, used to improve the search quality of the service.
          The identifiers (such as ``user_id``) are provided by users,
          and must be unique and consistent.
      job_query:
          Query used to search against jobs, such as keyword, location
          filters, etc.
      enable_broadening:
          Controls whether to broaden the search when it produces sparse
          results. Broadened queries append results to the end of the
          matching results list.  Defaults to false.
      require_precise_result_size:
          Controls if the search job request requires the return of a
          precise count of the first 300 results. Setting this to
          ``true`` ensures consistency in the number of results per
          page. Best practice is to set this value to true if a client
          allows users to jump directly to a non-sequential search
          results page.  Enabling this flag may adversely impact
          performance.  Defaults to false.
      histogram_queries:
          An expression specifies a histogram request against matching
          jobs.  Expression syntax is an aggregation function call with
          histogram facets and other options.  Available aggregation
          function calls are: \* ``count(string_histogram_facet)``:
          Count the number of matching entities, for each distinct
          attribute value. \* ``count(numeric_histogram_facet, list of
          buckets)``: Count the number of matching entities within each
          bucket.  Data types:  -  Histogram facet: facet names with
          format [a-zA-Z][a-zA-Z0-9\_]+. -  String: string like "any
          string with backslash escape for quote(")." -  Number: whole
          number and floating point number like 10, -1 and -0.01. -
          List: list of elements with comma(,) separator surrounded by
          square    brackets, for example, [1, 2, 3] and ["one", "two",
          "three"].  Built-in constants:  -  MIN (minimum number similar
          to java Double.MIN\_VALUE) -  MAX (maximum number similar to
          java Double.MAX\_VALUE)  Built-in functions:  -  bucket(start,
          end[, label]): bucket built-in function creates a    bucket
          with range of [start, end). Note that the end is exclusive,
          for example, bucket(1, MAX, "positive number") or bucket(1,
          10).  Job histogram facets:  -  company\_display\_name:
          histogram by    [Job.company\_display\_name][google.cloud.tale
          nt.v4beta1.Job.company\_display\_name]. -  employment\_type:
          histogram by    [Job.employment\_types][google.cloud.talent.v4
          beta1.Job.employment\_types],    for example, "FULL\_TIME",
          "PART\_TIME". -  company\_size: histogram by
          [CompanySize][google.cloud.talent.v4beta1.CompanySize], for
          example,    "SMALL", "MEDIUM", "BIG". -
          publish\_time\_in\_month: histogram by the    [Job.posting\_pu
          blish\_time][google.cloud.talent.v4beta1.Job.posting\_publish\
          _time]    in months. Must specify list of numeric buckets in
          spec. -  publish\_time\_in\_year: histogram by the    [Job.pos
          ting\_publish\_time][google.cloud.talent.v4beta1.Job.posting\_
          publish\_time]    in years. Must specify list of numeric
          buckets in spec. -  degree\_types: histogram by the    [Job.de
          gree\_types][google.cloud.talent.v4beta1.Job.degree\_types],
          for example, "Bachelors", "Masters". -  job\_level: histogram
          by the
          [Job.job\_level][google.cloud.talent.v4beta1.Job.job\_level],
          for    example, "Entry Level". -  country: histogram by the
          country code of jobs, for example, "US",    "FR". -  admin1:
          histogram by the admin1 code of jobs, which is a global
          placeholder referring to the state, province, or the
          particular term    a country uses to define the geographic
          structure below the country    level, for example, "CA", "IL".
          -  city: histogram by a combination of the "city name, admin1
          code". For    example, "Mountain View, CA", "New York, NY". -
          admin1\_country: histogram by a combination of the "admin1
          code,    country", for example, "CA, US", "IL, US". -
          city\_coordinate: histogram by the city center's GPS
          coordinates    (latitude and longitude), for example,
          37.4038522,-122.0987765. Since    the coordinates of a city
          center can change, customers may need to    refresh them
          periodically. -  locale: histogram by the    [Job.language\_co
          de][google.cloud.talent.v4beta1.Job.language\_code],    for
          example, "en-US", "fr-FR". -  language: histogram by the
          language subtag of the    [Job.language\_code][google.cloud.ta
          lent.v4beta1.Job.language\_code],    for example, "en", "fr".
          -  category: histogram by the
          [JobCategory][google.cloud.talent.v4beta1.JobCategory], for
          example,    "COMPUTER\_AND\_IT", "HEALTHCARE". -
          base\_compensation\_unit: histogram by the    [CompensationInf
          o.CompensationUnit][google.cloud.talent.v4beta1.CompensationIn
          fo.CompensationUnit]    of base salary, for example, "WEEKLY",
          "MONTHLY". -  base\_compensation: histogram by the base
          salary. Must specify list    of numeric buckets to group
          results by. -  annualized\_base\_compensation: histogram by
          the base annualized    salary. Must specify list of numeric
          buckets to group results by. -
          annualized\_total\_compensation: histogram by the total
          annualized    salary. Must specify list of numeric buckets to
          group results by. -  string\_custom\_attribute: histogram by
          string    [Job.custom\_attributes][google.cloud.talent.v4beta1
          .Job.custom\_attributes].    Values can be accessed via square
          bracket notations like    string\_custom\_attribute["key1"]. -
          numeric\_custom\_attribute: histogram by numeric    [Job.custo
          m\_attributes][google.cloud.talent.v4beta1.Job.custom\_attribu
          tes].    Values can be accessed via square bracket notations
          like    numeric\_custom\_attribute["key1"]. Must specify list
          of numeric    buckets to group results by.  Example
          expressions:  -  ``count(admin1)`` -
          ``count(base_compensation, [bucket(1000, 10000), bucket(10000,
          100000), bucket(100000, MAX)])`` -
          ``count(string_custom_attribute["some-string-custom-
          attribute"])`` -  ``count(numeric_custom_attribute["some-
          numeric-custom-attribute"],   [bucket(MIN, 0, "negative"),
          bucket(0, MAX, "non-negative"])``
      job_view:
          The desired job attributes returned for jobs in the search
          response. Defaults to [JobView.JOB\_VIEW\_SMALL][google.cloud.
          talent.v4beta1.JobView.JOB\_VIEW\_SMALL] if no value is
          specified.
      offset:
          An integer that specifies the current offset (that is,
          starting result location, amongst the jobs deemed by the API
          as relevant) in search results. This field is only considered
          if [page\_token][google.cloud.talent.v4beta1.SearchJobsRequest
          .page\_token] is unset.  The maximum allowed value is 5000.
          Otherwise an error is thrown.  The maximum allowed value is
          5000. Otherwise an error is thrown.  For example, 0 means to
          return results starting from the first matching job, and 10
          means to return from the 11th job. This can be used for
          pagination, (for example, pageSize = 10 and offset = 10 means
          to return from the second page).
      page_size:
          A limit on the number of jobs returned in the search results.
          Increasing this value above the default value of 10 can
          increase search response time. The value can be between 1 and
          100.
      page_token:
          The token specifying the current offset within search results.
          See [SearchJobsResponse.next\_page\_token][google.cloud.talent
          .v4beta1.SearchJobsResponse.next\_page\_token] for an
          explanation of how to obtain the next set of query results.
      order_by:
          The criteria determining how search results are sorted.
          Default is ``"relevance desc"``.  Supported options are:  -
          ``"relevance desc"``: By relevance descending, as determined
          by the    API algorithms. Relevance thresholding of query
          results is only    available with this ordering. -
          ``"posting_publish_time desc"``: By    [Job.posting\_publish\_
          time][google.cloud.talent.v4beta1.Job.posting\_publish\_time]
          descending. -  ``"posting_update_time desc"``: By    [Job.post
          ing\_update\_time][google.cloud.talent.v4beta1.Job.posting\_up
          date\_time]    descending. -  ``"title"``: By
          [Job.title][google.cloud.talent.v4beta1.Job.title]
          ascending. -  ``"title desc"``: By
          [Job.title][google.cloud.talent.v4beta1.Job.title] descending.
          -  ``"annualized_base_compensation"``: By job's    [Compensati
          onInfo.annualized\_base\_compensation\_range][google.cloud.tal
          ent.v4beta1.CompensationInfo.annualized\_base\_compensation\_r
          ange]    ascending. Jobs whose annualized base compensation is
          unspecified are    put at the end of search results. -
          ``"annualized_base_compensation desc"``: By job's    [Compensa
          tionInfo.annualized\_base\_compensation\_range][google.cloud.t
          alent.v4beta1.CompensationInfo.annualized\_base\_compensation\
          _range]    descending. Jobs whose annualized base compensation
          is unspecified    are put at the end of search results. -
          ``"annualized_total_compensation"``: By job's    [Compensation
          Info.annualized\_total\_compensation\_range][google.cloud.tale
          nt.v4beta1.CompensationInfo.annualized\_total\_compensation\_r
          ange]    ascending. Jobs whose annualized base compensation is
          unspecified are    put at the end of search results. -
          ``"annualized_total_compensation desc"``: By job's    [Compens
          ationInfo.annualized\_total\_compensation\_range][google.cloud
          .talent.v4beta1.CompensationInfo.annualized\_total\_compensati
          on\_range]    descending. Jobs whose annualized base
          compensation is unspecified    are put at the end of search
          results. -  ``"custom_ranking desc"``: By the relevance score
          adjusted to the    [SearchJobsRequest.CustomRankingInfo.rankin
          g\_expression][google.cloud.talent.v4beta1.SearchJobsRequest.C
          ustomRankingInfo.ranking\_expression]    with weight factor
          assigned by    [SearchJobsRequest.CustomRankingInfo.importance
          \_level][google.cloud.talent.v4beta1.SearchJobsRequest.CustomR
          ankingInfo.importance\_level]    in descending order. -
          Location sorting: Use the special syntax to order jobs by
          distance:    ``"distance_from('Hawaii')"``: Order by distance
          from Hawaii.    ``"distance_from(19.89, 155.5)"``: Order by
          distance from a    coordinate.    ``"distance_from('Hawaii'),
          distance_from('Puerto Rico')"``: Order by    multiple
          locations. See details below.    ``"distance_from('Hawaii'),
          distance_from(19.89, 155.5)"``: Order by    multiple
          locations. See details below. The string can have a maximum
          of 256 characters. When multiple distance centers are
          provided, a job    that is close to any of the distance
          centers would have a high rank.    When a job has multiple
          locations, the job location closest to one of    the distance
          centers will be used. Jobs that don't have locations    will
          be ranked at the bottom. Distance is calculated with a
          precision    of 11.3 meters (37.4 feet). Diversification
          strategy is still applied    unless explicitly disabled in    
          [diversification\_level][google.cloud.talent.v4beta1.SearchJob
          sRequest.diversification\_level].
      diversification_level:
          Controls whether highly similar jobs are returned next to each
          other in the search results. Jobs are identified as highly
          similar based on their titles, job categories, and locations.
          Highly similar results are clustered so that only one
          representative job of the cluster is displayed to the job
          seeker higher up in the results, with the other jobs being
          displayed lower down in the results.  Defaults to [Diversifica
          tionLevel.SIMPLE][google.cloud.talent.v4beta1.SearchJobsReques
          t.DiversificationLevel.SIMPLE] if no value is specified.
      custom_ranking_info:
          Controls over how job documents get ranked on top of existing
          relevance score (determined by API algorithm).
      disable_keyword_match:
          Controls whether to disable exact keyword match on
          [Job.title][google.cloud.talent.v4beta1.Job.title], [Job.descr
          iption][google.cloud.talent.v4beta1.Job.description], [Job.com
          pany\_display\_name][google.cloud.talent.v4beta1.Job.company\_
          display\_name],
          [Job.addresses][google.cloud.talent.v4beta1.Job.addresses], [J
          ob.qualifications][google.cloud.talent.v4beta1.Job.qualificati
          ons]. When disable keyword match is turned off, a keyword
          match returns jobs that do not match given category filters
          when there are matching keywords. For example, for the query
          "program manager," a result is returned even if the job
          posting has the title "software developer," which doesn't fall
          into "program manager" ontology, but does have "program
          manager" appearing in its description.  For queries like
          "cloud" that don't contain title or location specific
          ontology, jobs with "cloud" keyword matches are returned
          regardless of this flag's value.  Use [Company.keyword\_search
          able\_job\_custom\_attributes][google.cloud.talent.v4beta1.Com
          pany.keyword\_searchable\_job\_custom\_attributes] if company-
          specific globally matched custom field/attribute string values
          are needed. Enabling keyword match improves recall of
          subsequent search requests.  Defaults to false.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.SearchJobsRequest)
    ),
)
_sym_db.RegisterMessage(SearchJobsRequest)
_sym_db.RegisterMessage(SearchJobsRequest.CustomRankingInfo)

SearchJobsResponse = _reflection.GeneratedProtocolMessageType(
    "SearchJobsResponse",
    (_message.Message,),
    dict(
        MatchingJob=_reflection.GeneratedProtocolMessageType(
            "MatchingJob",
            (_message.Message,),
            dict(
                DESCRIPTOR=_SEARCHJOBSRESPONSE_MATCHINGJOB,
                __module__="google.cloud.talent_v4beta1.proto.job_service_pb2",
                __doc__="""Job entry with metadata inside
    [SearchJobsResponse][google.cloud.talent.v4beta1.SearchJobsResponse].
    
    
    Attributes:
        job:
            Job resource that matches the specified [SearchJobsRequest][go
            ogle.cloud.talent.v4beta1.SearchJobsRequest].
        job_summary:
            A summary of the job with core information that's displayed on
            the search results listing page.
        job_title_snippet:
            Contains snippets of text from the
            [Job.title][google.cloud.talent.v4beta1.Job.title] field most
            closely matching a search query's keywords, if available. The
            matching query keywords are enclosed in HTML bold tags.
        search_text_snippet:
            Contains snippets of text from the
            [Job.description][google.cloud.talent.v4beta1.Job.description]
            and similar fields that most closely match a search query's
            keywords, if available. All HTML tags in the original fields
            are stripped when returned in this field, and matching query
            keywords are enclosed in HTML bold tags.
        commute_info:
            Commute information which is generated based on specified
            [CommuteFilter][google.cloud.talent.v4beta1.CommuteFilter].
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.SearchJobsResponse.MatchingJob)
            ),
        ),
        CommuteInfo=_reflection.GeneratedProtocolMessageType(
            "CommuteInfo",
            (_message.Message,),
            dict(
                DESCRIPTOR=_SEARCHJOBSRESPONSE_COMMUTEINFO,
                __module__="google.cloud.talent_v4beta1.proto.job_service_pb2",
                __doc__="""Commute details related to this job.
    
    
    Attributes:
        job_location:
            Location used as the destination in the commute calculation.
        travel_duration:
            The number of seconds required to travel to the job location
            from the query location. A duration of 0 seconds indicates
            that the job isn't reachable within the requested duration,
            but was returned as part of an expanded query.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.SearchJobsResponse.CommuteInfo)
            ),
        ),
        DESCRIPTOR=_SEARCHJOBSRESPONSE,
        __module__="google.cloud.talent_v4beta1.proto.job_service_pb2",
        __doc__="""Response for SearchJob method.
  
  
  Attributes:
      matching_jobs:
          The Job entities that match the specified [SearchJobsRequest][
          google.cloud.talent.v4beta1.SearchJobsRequest].
      histogram_query_results:
          The histogram results that match with specified [SearchJobsReq
          uest.histogram\_queries][google.cloud.talent.v4beta1.SearchJob
          sRequest.histogram\_queries].
      next_page_token:
          The token that specifies the starting position of the next
          page of results. This field is empty if there are no more
          results.
      location_filters:
          The location filters that the service applied to the specified
          query. If any filters are lat-lng based, the [Location.locatio
          n\_type][google.cloud.talent.v4beta1.Location.location\_type]
          is [Location.LocationType.LOCATION\_TYPE\_UNSPECIFIED][google.
          cloud.talent.v4beta1.Location.LocationType.LOCATION\_TYPE\_UNS
          PECIFIED].
      estimated_total_size:
          An estimation of the number of jobs that match the specified
          query.  This number isn't guaranteed to be accurate. For
          accurate results, see [SearchJobsRequest.require\_precise\_res
          ult\_size][google.cloud.talent.v4beta1.SearchJobsRequest.requi
          re\_precise\_result\_size].
      total_size:
          The precise result count, which is available only if the
          client set [SearchJobsRequest.require\_precise\_result\_size][
          google.cloud.talent.v4beta1.SearchJobsRequest.require\_precise
          \_result\_size] to ``true``, or if the response is the last
          page of results. Otherwise, the value is ``-1``.
      metadata:
          Additional information for the API invocation, such as the
          request tracking id.
      broadened_query_jobs_count:
          If query broadening is enabled, we may append additional
          results from the broadened query. This number indicates how
          many of the jobs returned in the jobs field are from the
          broadened query. These results are always at the end of the
          jobs list. In particular, a value of 0, or if the field isn't
          set, all the jobs in the jobs list are from the original
          (without broadening) query. If this field is non-zero,
          subsequent requests with offset after this result set should
          contain all broadened results.
      spell_correction:
          The spell checking result, and correction.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.SearchJobsResponse)
    ),
)
_sym_db.RegisterMessage(SearchJobsResponse)
_sym_db.RegisterMessage(SearchJobsResponse.MatchingJob)
_sym_db.RegisterMessage(SearchJobsResponse.CommuteInfo)

BatchCreateJobsRequest = _reflection.GeneratedProtocolMessageType(
    "BatchCreateJobsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_BATCHCREATEJOBSREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.job_service_pb2",
        __doc__="""Request to create a batch of jobs.
  
  
  Attributes:
      parent:
          Required. The resource name of the tenant under which the job
          is created.  The format is
          "projects/{project\_id}/tenants/{tenant\_id}". For example,
          "projects/foo/tenant/bar". If tenant id is unspecified, a
          default tenant is created. For example, "projects/foo".
      jobs:
          Required. The jobs to be created.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.BatchCreateJobsRequest)
    ),
)
_sym_db.RegisterMessage(BatchCreateJobsRequest)

BatchUpdateJobsRequest = _reflection.GeneratedProtocolMessageType(
    "BatchUpdateJobsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_BATCHUPDATEJOBSREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.job_service_pb2",
        __doc__="""Request to update a batch of jobs.
  
  
  Attributes:
      parent:
          Required. The resource name of the tenant under which the job
          is created.  The format is
          "projects/{project\_id}/tenants/{tenant\_id}". For example,
          "projects/foo/tenant/bar". If tenant id is unspecified, a
          default tenant is created. For example, "projects/foo".
      jobs:
          Required. The jobs to be updated.
      update_mask:
          Strongly recommended for the best service experience. Be aware
          that it will also increase latency when checking the status of
          a batch operation.  If [update\_mask][google.cloud.talent.v4be
          ta1.BatchUpdateJobsRequest.update\_mask] is provided, only the
          specified fields in [Job][google.cloud.talent.v4beta1.Job] are
          updated. Otherwise all the fields are updated.  A field mask
          to restrict the fields that are updated. Only top level fields
          of [Job][google.cloud.talent.v4beta1.Job] are supported.  If [
          update\_mask][google.cloud.talent.v4beta1.BatchUpdateJobsReque
          st.update\_mask] is provided, The
          [Job][google.cloud.talent.v4beta1.Job] inside [JobResult][goog
          le.cloud.talent.v4beta1.JobOperationResult.JobResult] will
          only contains fields that is updated, plus the Id of the Job.
          Otherwise, [Job][google.cloud.talent.v4beta1.Job] will include
          all fields, which can yield a very large response.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.BatchUpdateJobsRequest)
    ),
)
_sym_db.RegisterMessage(BatchUpdateJobsRequest)

JobOperationResult = _reflection.GeneratedProtocolMessageType(
    "JobOperationResult",
    (_message.Message,),
    dict(
        JobResult=_reflection.GeneratedProtocolMessageType(
            "JobResult",
            (_message.Message,),
            dict(
                DESCRIPTOR=_JOBOPERATIONRESULT_JOBRESULT,
                __module__="google.cloud.talent_v4beta1.proto.job_service_pb2",
                __doc__="""Mutation result of a job.
    
    
    Attributes:
        job:
            Here [Job][google.cloud.talent.v4beta1.Job] only contains
            basic information including
            [name][google.cloud.talent.v4beta1.Job.name],
            [company][google.cloud.talent.v4beta1.Job.company], [language\
            _code][google.cloud.talent.v4beta1.Job.language\_code] and [re
            quisition\_id][google.cloud.talent.v4beta1.Job.requisition\_id
            ], use getJob method to retrieve detailed information of the
            created/updated job.
        status:
            The status of the job processed. This field is populated if
            the processing of the [job][google.cloud.talent.v4beta1.JobOpe
            rationResult.JobResult.job] fails.
    """,
                # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.JobOperationResult.JobResult)
            ),
        ),
        DESCRIPTOR=_JOBOPERATIONRESULT,
        __module__="google.cloud.talent_v4beta1.proto.job_service_pb2",
        __doc__="""The result of
  [JobService.BatchCreateJobs][google.cloud.talent.v4beta1.JobService.BatchCreateJobs]
  or
  [JobService.BatchUpdateJobs][google.cloud.talent.v4beta1.JobService.BatchUpdateJobs]
  APIs. It's used to replace
  [google.longrunning.Operation.response][google.longrunning.Operation.response]
  in case of success.
  
  
  Attributes:
      job_results:
          List of job mutation results from a batch mutate operation. It
          can change until operation status is FINISHED, FAILED or
          CANCELLED.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.JobOperationResult)
    ),
)
_sym_db.RegisterMessage(JobOperationResult)
_sym_db.RegisterMessage(JobOperationResult.JobResult)


DESCRIPTOR._options = None
_CREATEJOBREQUEST.fields_by_name["parent"]._options = None
_CREATEJOBREQUEST.fields_by_name["job"]._options = None
_GETJOBREQUEST.fields_by_name["name"]._options = None
_UPDATEJOBREQUEST.fields_by_name["job"]._options = None
_DELETEJOBREQUEST.fields_by_name["name"]._options = None
_BATCHDELETEJOBSREQUEST.fields_by_name["parent"]._options = None
_BATCHDELETEJOBSREQUEST.fields_by_name["filter"]._options = None
_LISTJOBSREQUEST.fields_by_name["parent"]._options = None
_LISTJOBSREQUEST.fields_by_name["filter"]._options = None
_SEARCHJOBSREQUEST_CUSTOMRANKINGINFO.fields_by_name["importance_level"]._options = None
_SEARCHJOBSREQUEST_CUSTOMRANKINGINFO.fields_by_name[
    "ranking_expression"
]._options = None
_SEARCHJOBSREQUEST.fields_by_name["parent"]._options = None
_SEARCHJOBSREQUEST.fields_by_name["request_metadata"]._options = None
_BATCHCREATEJOBSREQUEST.fields_by_name["parent"]._options = None
_BATCHCREATEJOBSREQUEST.fields_by_name["jobs"]._options = None
_BATCHUPDATEJOBSREQUEST.fields_by_name["parent"]._options = None
_BATCHUPDATEJOBSREQUEST.fields_by_name["jobs"]._options = None

_JOBSERVICE = _descriptor.ServiceDescriptor(
    name="JobService",
    full_name="google.cloud.talent.v4beta1.JobService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=_b(
        "\312A\023jobs.googleapis.com\322AShttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/jobs"
    ),
    serialized_start=4108,
    serialized_end=6490,
    methods=[
        _descriptor.MethodDescriptor(
            name="CreateJob",
            full_name="google.cloud.talent.v4beta1.JobService.CreateJob",
            index=0,
            containing_service=None,
            input_type=_CREATEJOBREQUEST,
            output_type=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2._JOB,
            serialized_options=_b(
                '\202\323\344\223\002X"+/v4beta1/{parent=projects/*/tenants/*}/jobs:\001*Z&"!/v4beta1/{parent=projects/*}/jobs:\001*\332A\nparent,job'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="BatchCreateJobs",
            full_name="google.cloud.talent.v4beta1.JobService.BatchCreateJobs",
            index=1,
            containing_service=None,
            input_type=_BATCHCREATEJOBSREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\002p"7/v4beta1/{parent=projects/*/tenants/*}/jobs:batchCreate:\001*Z2"-/v4beta1/{parent=projects/*}/jobs:batchCreate:\001*\332A\013parent,jobs\312A,\n\022JobOperationResult\022\026BatchOperationMetadata'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetJob",
            full_name="google.cloud.talent.v4beta1.JobService.GetJob",
            index=2,
            containing_service=None,
            input_type=_GETJOBREQUEST,
            output_type=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2._JOB,
            serialized_options=_b(
                "\202\323\344\223\002R\022+/v4beta1/{name=projects/*/tenants/*/jobs/*}Z#\022!/v4beta1/{name=projects/*/jobs/*}\332A\004name"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UpdateJob",
            full_name="google.cloud.talent.v4beta1.JobService.UpdateJob",
            index=3,
            containing_service=None,
            input_type=_UPDATEJOBREQUEST,
            output_type=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_job__pb2._JOB,
            serialized_options=_b(
                "\202\323\344\223\002`2//v4beta1/{job.name=projects/*/tenants/*/jobs/*}:\001*Z*2%/v4beta1/{job.name=projects/*/jobs/*}:\001*\332A\003job"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="BatchUpdateJobs",
            full_name="google.cloud.talent.v4beta1.JobService.BatchUpdateJobs",
            index=4,
            containing_service=None,
            input_type=_BATCHUPDATEJOBSREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\002p"7/v4beta1/{parent=projects/*/tenants/*}/jobs:batchUpdate:\001*Z2"-/v4beta1/{parent=projects/*}/jobs:batchUpdate:\001*\332A\013parent,jobs\312A,\n\022JobOperationResult\022\026BatchOperationMetadata'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="DeleteJob",
            full_name="google.cloud.talent.v4beta1.JobService.DeleteJob",
            index=5,
            containing_service=None,
            input_type=_DELETEJOBREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=_b(
                "\202\323\344\223\002R*+/v4beta1/{name=projects/*/tenants/*/jobs/*}Z#*!/v4beta1/{name=projects/*/jobs/*}\332A\004name"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="BatchDeleteJobs",
            full_name="google.cloud.talent.v4beta1.JobService.BatchDeleteJobs",
            index=6,
            containing_service=None,
            input_type=_BATCHDELETEJOBSREQUEST,
            output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
            serialized_options=_b(
                '\202\323\344\223\002m"7/v4beta1/{parent=projects/*/tenants/*}/jobs:batchDelete:\001*Z/"-/v4beta1/{parent=projects/*}/jobs:batchDelete\332A\rparent,filter'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ListJobs",
            full_name="google.cloud.talent.v4beta1.JobService.ListJobs",
            index=7,
            containing_service=None,
            input_type=_LISTJOBSREQUEST,
            output_type=_LISTJOBSRESPONSE,
            serialized_options=_b(
                "\202\323\344\223\002R\022+/v4beta1/{parent=projects/*/tenants/*}/jobsZ#\022!/v4beta1/{parent=projects/*}/jobs\332A\rparent,filter"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="SearchJobs",
            full_name="google.cloud.talent.v4beta1.JobService.SearchJobs",
            index=8,
            containing_service=None,
            input_type=_SEARCHJOBSREQUEST,
            output_type=_SEARCHJOBSRESPONSE,
            serialized_options=_b(
                '\202\323\344\223\002f"2/v4beta1/{parent=projects/*/tenants/*}/jobs:search:\001*Z-"(/v4beta1/{parent=projects/*}/jobs:search:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="SearchJobsForAlert",
            full_name="google.cloud.talent.v4beta1.JobService.SearchJobsForAlert",
            index=9,
            containing_service=None,
            input_type=_SEARCHJOBSREQUEST,
            output_type=_SEARCHJOBSRESPONSE,
            serialized_options=_b(
                '\202\323\344\223\002v":/v4beta1/{parent=projects/*/tenants/*}/jobs:searchForAlert:\001*Z5"0/v4beta1/{parent=projects/*}/jobs:searchForAlert:\001*'
            ),
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_JOBSERVICE)

DESCRIPTOR.services_by_name["JobService"] = _JOBSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""Unit tests."""

import mock
import pytest

from google.cloud import talent_v4beta1
from google.cloud.talent_v4beta1.proto import tenant_pb2
from google.cloud.talent_v4beta1.proto import tenant_service_pb2
from google.protobuf import empty_pb2


class MultiCallableStub(object):
    """Stub for the grpc.UnaryUnaryMultiCallable interface."""

    def __init__(self, method, channel_stub):
        self.method = method
        self.channel_stub = channel_stub

    def __call__(self, request, timeout=None, metadata=None, credentials=None):
        self.channel_stub.requests.append((self.method, request))

        response = None
        if self.channel_stub.responses:
            response = self.channel_stub.responses.pop()

        if isinstance(response, Exception):
            raise response

        if response:
            return response


class ChannelStub(object):
    """Stub for the grpc.Channel interface."""

    def __init__(self, responses=[]):
        self.responses = responses
        self.requests = []

    def unary_unary(self, method, request_serializer=None, response_deserializer=None):
        return MultiCallableStub(method, self)


class CustomException(Exception):
    pass


class TestTenantServiceClient(object):
    def test_create_tenant(self):
        # Setup Expected Response
        name = "name3373707"
        external_id = "externalId-1153075697"
        expected_response = {"name": name, "external_id": external_id}
        expected_response = tenant_pb2.Tenant(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.TenantServiceClient()

        # Setup Request
        parent = client.project_path("[PROJECT]")
        tenant = {}

        response = client.create_tenant(parent, tenant)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = tenant_service_pb2.CreateTenantRequest(
            parent=parent, tenant=tenant
        )
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_create_tenant_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.TenantServiceClient()

        # Setup request
        parent = client.project_path("[PROJECT]")
        tenant = {}

        with pytest.raises(CustomException):
            client.create_tenant(parent, tenant)

    def test_get_tenant(self):
        # Setup Expected Response
        name_2 = "name2-1052831874"
        external_id = "externalId-1153075697"
        expected_response = {"name": name_2, "external_id": external_id}
        expected_response = tenant_pb2.Tenant(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.TenantServiceClient()

        # Setup Request
        name = client.tenant_path("[PROJECT]", "[TENANT]")

        response = client.get_tenant(name)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = tenant_service_pb2.GetTenantRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_get_tenant_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.TenantServiceClient()

        # Setup request
        name = client.tenant_path("[PROJECT]", "[TENANT]")

        with pytest.raises(CustomException):
            client.get_tenant(name)

    def test_update_tenant(self):
        # Setup Expected Response
        name = "name3373707"
        external_id = "externalId-1153075697"
        expected_response = {"name": name, "external_id": external_id}
        expected_response = tenant_pb2.Tenant(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.TenantServiceClient()

        # Setup Request
        tenant = {}

        response = client.update_tenant(tenant)
        assert expected_response == response

        assert len(channel.requests) == 1
        expected_request = tenant_service_pb2.UpdateTenantRequest(tenant=tenant)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_update_tenant_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.TenantServiceClient()

        # Setup request
        tenant = {}

        with pytest.raises(CustomException):
            client.update_tenant(tenant)

    def test_delete_tenant(self):
        channel = ChannelStub()
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.TenantServiceClient()

        # Setup Request
        name = client.tenant_path("[PROJECT]", "[TENANT]")

        client.delete_tenant(name)

        assert len(channel.requests) == 1
        expected_request = tenant_service_pb2.DeleteTenantRequest(name=name)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_delete_tenant_exception(self):
        # Mock the API response
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.TenantServiceClient()

        # Setup request
        name = client.tenant_path("[PROJECT]", "[TENANT]")

        with pytest.raises(CustomException):
            client.delete_tenant(name)

    def test_list_tenants(self):
        # Setup Expected Response
        next_page_token = ""
        tenants_element = {}
        tenants = [tenants_element]
        expected_response = {"next_page_token": next_page_token, "tenants": tenants}
        expected_response = tenant_service_pb2.ListTenantsResponse(**expected_response)

        # Mock the API response
        channel = ChannelStub(responses=[expected_response])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.TenantServiceClient()

        # Setup Request
        parent = client.project_path("[PROJECT]")

        paged_list_response = client.list_tenants(parent)
        resources = list(paged_list_response)
        assert len(resources) == 1

        assert expected_response.tenants[0] == resources[0]

        assert len(channel.requests) == 1
        expected_request = tenant_service_pb2.ListTenantsRequest(parent=parent)
        actual_request = channel.requests[0][1]
        assert expected_request == actual_request

    def test_list_tenants_exception(self):
        channel = ChannelStub(responses=[CustomException()])
        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
        with patch as create_channel:
            create_channel.return_value = channel
            client = talent_v4beta1.TenantServiceClient()

        # Setup request
        parent = client.project_path("[PROJECT]")

        paged_list_response = client.list_tenants(parent)
        with pytest.raises(CustomException):
            list(paged_list_response)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/talent_v4beta1/proto/event_service.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.talent_v4beta1.proto import (
    event_pb2 as google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_event__pb2,
)


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/talent_v4beta1/proto/event_service.proto",
    package="google.cloud.talent.v4beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.talent.v4beta1B\021EventServiceProtoP\001ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\242\002\003CTS"
    ),
    serialized_pb=_b(
        '\n5google/cloud/talent_v4beta1/proto/event_service.proto\x12\x1bgoogle.cloud.talent.v4beta1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x19google/api/resource.proto\x1a-google/cloud/talent_v4beta1/proto/event.proto"\x9c\x01\n\x18\x43reateClientEventRequest\x12;\n\x06parent\x18\x01 \x01(\tB+\xe0\x41\x02\xfa\x41%\n#jobs.googleapis.com/TenantOrProject\x12\x43\n\x0c\x63lient_event\x18\x02 \x01(\x0b\x32(.google.cloud.talent.v4beta1.ClientEventB\x03\xe0\x41\x02\x32\xfa\x02\n\x0c\x45ventService\x12\xfb\x01\n\x11\x43reateClientEvent\x12\x35.google.cloud.talent.v4beta1.CreateClientEventRequest\x1a(.google.cloud.talent.v4beta1.ClientEvent"\x84\x01\x82\xd3\xe4\x93\x02h"3/v4beta1/{parent=projects/*/tenants/*}/clientEvents:\x01*Z.")/v4beta1/{parent=projects/*}/clientEvents:\x01*\xda\x41\x13parent,client_event\x1al\xca\x41\x13jobs.googleapis.com\xd2\x41Shttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/jobsB\x7f\n\x1f\x63om.google.cloud.talent.v4beta1B\x11\x45ventServiceProtoP\x01ZAgoogle.golang.org/genproto/googleapis/cloud/talent/v4beta1;talent\xa2\x02\x03\x43TSb\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_field__behavior__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_event__pb2.DESCRIPTOR,
    ],
)


_CREATECLIENTEVENTREQUEST = _descriptor.Descriptor(
    name="CreateClientEventRequest",
    full_name="google.cloud.talent.v4beta1.CreateClientEventRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.talent.v4beta1.CreateClientEventRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b(
                "\340A\002\372A%\n#jobs.googleapis.com/TenantOrProject"
            ),
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="client_event",
            full_name="google.cloud.talent.v4beta1.CreateClientEventRequest.client_event",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=_b("\340A\002"),
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=249,
    serialized_end=405,
)

_CREATECLIENTEVENTREQUEST.fields_by_name[
    "client_event"
].message_type = (
    google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_event__pb2._CLIENTEVENT
)
DESCRIPTOR.message_types_by_name["CreateClientEventRequest"] = _CREATECLIENTEVENTREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateClientEventRequest = _reflection.GeneratedProtocolMessageType(
    "CreateClientEventRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CREATECLIENTEVENTREQUEST,
        __module__="google.cloud.talent_v4beta1.proto.event_service_pb2",
        __doc__="""The report event request.
  
  
  Attributes:
      parent:
          Required. Resource name of the tenant under which the event is
          created.  The format is
          "projects/{project\_id}/tenants/{tenant\_id}", for example,
          "projects/foo/tenant/bar". If tenant id is unspecified, a
          default tenant is created, for example, "projects/foo".
      client_event:
          Required. Events issued when end user interacts with
          customer's application that uses Cloud Talent Solution.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.talent.v4beta1.CreateClientEventRequest)
    ),
)
_sym_db.RegisterMessage(CreateClientEventRequest)


DESCRIPTOR._options = None
_CREATECLIENTEVENTREQUEST.fields_by_name["parent"]._options = None
_CREATECLIENTEVENTREQUEST.fields_by_name["client_event"]._options = None

_EVENTSERVICE = _descriptor.ServiceDescriptor(
    name="EventService",
    full_name="google.cloud.talent.v4beta1.EventService",
    file=DESCRIPTOR,
    index=0,
    serialized_options=_b(
        "\312A\023jobs.googleapis.com\322AShttps://www.googleapis.com/auth/cloud-platform,https://www.googleapis.com/auth/jobs"
    ),
    serialized_start=408,
    serialized_end=786,
    methods=[
        _descriptor.MethodDescriptor(
            name="CreateClientEvent",
            full_name="google.cloud.talent.v4beta1.EventService.CreateClientEvent",
            index=0,
            containing_service=None,
            input_type=_CREATECLIENTEVENTREQUEST,
            output_type=google_dot_cloud_dot_talent__v4beta1_dot_proto_dot_event__pb2._CLIENTEVENT,
            serialized_options=_b(
                '\202\323\344\223\002h"3/v4beta1/{parent=projects/*/tenants/*}/clientEvents:\001*Z.")/v4beta1/{parent=projects/*}/clientEvents:\001*\332A\023parent,client_event'
            ),
        )
    ],
)
_sym_db.RegisterServiceDescriptor(_EVENTSERVICE)

DESCRIPTOR.services_by_name["EventService"] = _EVENTSERVICE

# @@protoc_insertion_point(module_scope)
